@@ -5,8 +5,8 @@
 # Author          : Johan Vromans
 # Created On      : Tue Sep  6 16:09:10 2016
 # Last Modified By: Johan Vromans
-# Last Modified On: Tue Feb 28 13:51:29 2017
-# Update Count    : 68
+# Last Modified On: Tue Mar  7 11:25:23 2017
+# Update Count    : 76
 # Status          : Unknown, Use with caution!
 
 ################ Common stuff ################
@@ -18,7 +18,7 @@ use utf8;
 
 package Data::iRealPro::Input;
 
-our $VERSION = "1.03";
+our $VERSION = "1.05";
 
 use Data::iRealPro::URI;
 use Data::iRealPro::Input::Text;
@@ -31,7 +31,8 @@ sub new {
     my $self = bless( { variant => "irealpro" }, $pkg );
 
     for ( qw( trace debug verbose output variant transpose
-	      neatify select ) ) {
+	      neatify select suppress-upbeat suppress-text
+	      musescore override-alt condense ) ) {
 	$self->{$_} = $options->{$_} if exists $options->{$_};
     }
 
